{% extends 'allianceauth/base.html' %}
{% load i18n %}

{% block page_title %}{% translate "Example Plugin" %}{% endblock %}

{% block content %}
    <div class="allianceauth-example-plugin">
        <h1 class="page-header text-center">{% translate "Example Plugin" %}</h1>

        {% block details %}{% endblock %}
    </div>
{% endblock %}
