{% extends 'example/base.html' %}
{% load i18n %}
{% load humanize %}

{% block details %}
    <div class="panel panel-primary">
        <div class="panel-heading">
            <div class="panel-title">{% translate "Panel Headline" %}</div>
        </div>

        <div class="panel-body">
            {{ text }}
        </div>
    </div>
{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
